@@ -450,6 +450,12 @@ retval_t ScimBridgeAgentImpl::initialize_scim ()
         scim_bridge_perrorln ("There is no socket frontend of config module for SCIM...");
         return RETVAL_FAILED;
     }
+    
+    {
+    	scim_bridge_pdebugln (8, "Launching a SCIM daemon with x11 FrontEnd...");
+    	char *new_argv [] = {"--no-stay","-d", NULL};
+    	scim_launch (true, "socket", "socket", "x11", new_argv);
+    }
 
     // If there is no socket frontend running, launch one.
     if (!is_socket_frontend_ready ()) {
@@ -470,7 +476,7 @@ retval_t ScimBridgeAgentImpl::initialize_scim ()
             }
         }
     }
-
+    
     // load config module
     scim_bridge_pdebugln (2, "Loading Config module...: socket");
     scim_config_module = new ConfigModule ("socket");
